/* application.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from application.vala, do not modify */

/*
Copyright Buddies of Budgie

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

#include <gtk/gtk.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_BUDGIE_DESKTOP_VIEW_APP (budgie_desktop_view_app_get_type ())
#define BUDGIE_DESKTOP_VIEW_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BUDGIE_DESKTOP_VIEW_APP, BudgieDesktopViewApp))
#define BUDGIE_DESKTOP_VIEW_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BUDGIE_DESKTOP_VIEW_APP, BudgieDesktopViewAppClass))
#define IS_BUDGIE_DESKTOP_VIEW_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BUDGIE_DESKTOP_VIEW_APP))
#define IS_BUDGIE_DESKTOP_VIEW_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BUDGIE_DESKTOP_VIEW_APP))
#define BUDGIE_DESKTOP_VIEW_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BUDGIE_DESKTOP_VIEW_APP, BudgieDesktopViewAppClass))

typedef struct _BudgieDesktopViewApp BudgieDesktopViewApp;
typedef struct _BudgieDesktopViewAppClass BudgieDesktopViewAppClass;
typedef struct _BudgieDesktopViewAppPrivate BudgieDesktopViewAppPrivate;
enum  {
	BUDGIE_DESKTOP_VIEW_APP_0_PROPERTY,
	BUDGIE_DESKTOP_VIEW_APP_NUM_PROPERTIES
};
static GParamSpec* budgie_desktop_view_app_properties[BUDGIE_DESKTOP_VIEW_APP_NUM_PROPERTIES];

#define TYPE_DESKTOP_VIEW (desktop_view_get_type ())
#define DESKTOP_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DESKTOP_VIEW, DesktopView))
#define DESKTOP_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DESKTOP_VIEW, DesktopViewClass))
#define IS_DESKTOP_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DESKTOP_VIEW))
#define IS_DESKTOP_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DESKTOP_VIEW))
#define DESKTOP_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DESKTOP_VIEW, DesktopViewClass))

typedef struct _DesktopView DesktopView;
typedef struct _DesktopViewClass DesktopViewClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

struct _BudgieDesktopViewApp {
	GtkApplication parent_instance;
	BudgieDesktopViewAppPrivate * priv;
};

struct _BudgieDesktopViewAppClass {
	GtkApplicationClass parent_class;
};

static gpointer budgie_desktop_view_app_parent_class = NULL;

VALA_EXTERN GType budgie_desktop_view_app_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BudgieDesktopViewApp, g_object_unref)
VALA_EXTERN BudgieDesktopViewApp* budgie_desktop_view_app_new (void);
VALA_EXTERN BudgieDesktopViewApp* budgie_desktop_view_app_construct (GType object_type);
static void budgie_desktop_view_app_real_activate (GApplication* base);
VALA_EXTERN GType desktop_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DesktopView, g_object_unref)
VALA_EXTERN DesktopView* desktop_view_new (GtkApplication* app);
VALA_EXTERN DesktopView* desktop_view_construct (GType object_type,
                                     GtkApplication* app);
static gint budgie_desktop_view_app_main (gchar** args,
                                   gint args_length1);
static GType budgie_desktop_view_app_get_type_once (void);

BudgieDesktopViewApp*
budgie_desktop_view_app_construct (GType object_type)
{
	BudgieDesktopViewApp * self = NULL;
	self = (BudgieDesktopViewApp*) g_object_new (object_type, "application-id", "org.buddiesofbudgie.budgie-desktop-view", "flags", G_APPLICATION_FLAGS_NONE, NULL);
	return self;
}

BudgieDesktopViewApp*
budgie_desktop_view_app_new (void)
{
	return budgie_desktop_view_app_construct (TYPE_BUDGIE_DESKTOP_VIEW_APP);
}

static void
budgie_desktop_view_app_real_activate (GApplication* base)
{
	BudgieDesktopViewApp * self;
	DesktopView* view = NULL;
	DesktopView* _tmp0_;
	self = (BudgieDesktopViewApp*) base;
	_tmp0_ = desktop_view_new ((GtkApplication*) self);
	g_object_ref_sink (_tmp0_);
	view = _tmp0_;
	gtk_widget_show_all ((GtkWidget*) view);
	_g_object_unref0 (view);
}

static gint
budgie_desktop_view_app_main (gchar** args,
                              gint args_length1)
{
	BudgieDesktopViewApp* app = NULL;
	BudgieDesktopViewApp* _tmp0_;
	gint result;
	_tmp0_ = budgie_desktop_view_app_new ();
	app = _tmp0_;
	result = g_application_run ((GApplication*) app, (gint) args_length1, args);
	_g_object_unref0 (app);
	return result;
}

int
main (int argc,
      char ** argv)
{
	return budgie_desktop_view_app_main (argv, argc);
}

static void
budgie_desktop_view_app_class_init (BudgieDesktopViewAppClass * klass,
                                    gpointer klass_data)
{
	budgie_desktop_view_app_parent_class = g_type_class_peek_parent (klass);
	((GApplicationClass *) klass)->activate = (void (*) (GApplication*)) budgie_desktop_view_app_real_activate;
}

static void
budgie_desktop_view_app_instance_init (BudgieDesktopViewApp * self,
                                       gpointer klass)
{
}

 G_GNUC_NO_INLINE static GType
budgie_desktop_view_app_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (BudgieDesktopViewAppClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) budgie_desktop_view_app_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BudgieDesktopViewApp), 0, (GInstanceInitFunc) budgie_desktop_view_app_instance_init, NULL };
	GType budgie_desktop_view_app_type_id;
	budgie_desktop_view_app_type_id = g_type_register_static (gtk_application_get_type (), "BudgieDesktopViewApp", &g_define_type_info, 0);
	return budgie_desktop_view_app_type_id;
}

GType
budgie_desktop_view_app_get_type (void)
{
	static volatile gsize budgie_desktop_view_app_type_id__once = 0;
	if (g_once_init_enter (&budgie_desktop_view_app_type_id__once)) {
		GType budgie_desktop_view_app_type_id;
		budgie_desktop_view_app_type_id = budgie_desktop_view_app_get_type_once ();
		g_once_init_leave (&budgie_desktop_view_app_type_id__once, budgie_desktop_view_app_type_id);
	}
	return budgie_desktop_view_app_type_id__once;
}

